==> PickerExtended_2.4.0.zip: PickerExtended_2.4.0/prototypes/picker.lua <==
-- 'consuming'
-- available options:
-- none: default if not defined
-- all: if this is the first input to get this key sequence then no other inputs listening for this sequence are fired
-- script-only: if this is the first *custom* input to get this key sequence then no other *custom* inputs listening for this sequence are fired.
----Normal game inputs will still be fired even if they match this sequence.
-- game-only: The opposite of script-only: blocks game inputs using the same key sequence but lets other custom inputs using the same key sequence fire.
data:extend{
    {
        type = "custom-input",
        name = "picker-select",
        key_sequence = "Q",
    },
    {
        type = "custom-input",
        name = "picker-crafter",
        key_sequence = "ALT + Q",
    },
    {
        type = "custom-input",
        name = "picker-make-ghost",
        key_sequence = "CONTROL + Q",
        consuming = "all"
    },
    {
        type = "custom-input",
        name = "picker-copy-chest",
        key_sequence = "CONTROL + V",
        consuming = "all"
    },
    {
        type = "custom-input",
        name = "picker-pipe-cleaner",
        key_sequence = "CONTROL + DELETE",
        consuming = "none"
    },
    {
        type = "custom-input",
        name = "picker-wire-cutter",
        key_sequence = "CONTROL + DELETE",
        consuming = "none"
    },
    {
        type = "custom-input",
        name = "picker-wire-picker",
        key_sequence = "SHIFT + Q",
        consuming = "none"
    },
}

==> PickerExtended_2.6.0.zip: PickerExtended_2.6.0/prototypes/picker.lua <==
-- 'consuming'
-- available options:
-- none: default if not defined
-- all: if this is the first input to get this key sequence then no other inputs listening for this sequence are fired
-- script-only: if this is the first *custom* input to get this key sequence then no other *custom* inputs listening for this sequence are fired.
----Normal game inputs will still be fired even if they match this sequence.
-- game-only: The opposite of script-only: blocks game inputs using the same key sequence but lets other custom inputs using the same key sequence fire.
data:extend{
    {
        type = "custom-input",
        name = "picker-select",
        key_sequence = "Q",
    },
    {
        type = "custom-input",
        name = "picker-crafter",
        key_sequence = "ALT + Q",
    },
    {
        type = "custom-input",
        name = "picker-make-ghost",
        key_sequence = "CONTROL + Q",
        consuming = "all"
    },
    {
        type = "custom-input",
        name = "picker-copy-chest",
        key_sequence = "CONTROL + V",
        consuming = "all"
    },
    {
        type = "custom-input",
        name = "picker-pipe-cleaner",
        key_sequence = "CONTROL + DELETE",
        consuming = "none"
    },
    {
        type = "custom-input",
        name = "picker-wire-cutter",
        key_sequence = "CONTROL + DELETE",
        consuming = "none"
    },
    {
        type = "custom-input",
        name = "picker-wire-picker",
        key_sequence = "SHIFT + Q",
        consuming = "none"
    },
    {
        type = "custom-input",
        name = "picker-beltbrush-corners",
        key_sequence = "CONTROL + SHIFT + R",
        consuming = "none"
    },
    {
        type = "custom-input",
        name = "picker-beltbrush-balancers",
        key_sequence = "CONTROL + SHIFT + B",
        consuming = "all"
    },
    {
        type = "custom-input",
        name = "picker-mirror-blueprint",
        key_sequence = "ALT + R",
        consuming = "all"
    },
    {
        type = "custom-input",
        name = "picker-quick-picker",
        key_sequence = "CONTROL + SHIFT + ENTER",
        consuming = "all"
    },
    {
        type = "custom-input",
        name = "picker-inventory-editor",
        key_sequence = "CONTROL + SHIFT + GRAVE",
        consuming = "all"
    }
}

local text ={
    type = "flying-text",
    name = "picker-flying-text",
    flags = {"placeable-off-grid", "not-on-map"},
    time_to_live = 60,
    speed = 0.05
}
data:extend{text}
